@@ -1588,244 +1588,6 @@ gdk_imlib_data_to_pixmap(char **data, GdkPixmap ** pmap, GdkBitmap ** mask)
   return 1;
 }
 
-struct _io_info
-{
-  unsigned char *data;
-  unsigned char *ptr;
-  unsigned char *end;
-};
-
-#ifdef HAVE_LIBPNG
-static void 
-_gdk_imlib_png_io_read(png_structp png_ptr,
-	      png_bytep data, png_uint_32 size)
-{
-  struct _io_info *io_ptr;
-  int bytes;
-  
-  io_ptr = (struct _io_info *)png_get_io_ptr(png_ptr);
-  
-  if ((io_ptr->end - io_ptr->ptr) >= size)
-    {
-      memcpy(data, io_ptr->ptr, size);
-      io_ptr->ptr += size;
-      return;
-    }
-  bytes = io_ptr->end - io_ptr->ptr;
-  memcpy(data, io_ptr->ptr, bytes);
-  io_ptr->ptr = io_ptr->end;
-  return;
-}
-#endif /* HAVE_LIBPNG */
-
-GdkImlibImage *
-gdk_imlib_inlined_png_to_image(unsigned char *data, int data_size)
-{
-#ifdef HAVE_LIBPNG
-  GdkImlibImage      *im;
-  png_structp         png_ptr;
-  png_infop           info_ptr;
-  unsigned char      *ptr, **lines, *ptr2, r, g, b, a;
-  int                 i, x, y, transp, bit_depth, color_type, interlace_type;
-  png_uint_32         ww, hh;
-  struct _io_info     io_info;
-  char                s [64];
-  
-  if (!strcmp("1.0.2", png_libpng_ver))
-    {
-      fprintf(stderr, "WARNING! You have libpng 1.0.2\n"
-	      "It has a known bug that corrupts images on load.\n"
-	      "please use 1.0.1.\n");
-      return NULL;
-    }
-  im = malloc(sizeof(GdkImlibImage));
-  if (!im)
-    return NULL;
-  im->map = NULL;
-  im->rgb_width = 0;
-  im->rgb_height = 0;
-  im->rgb_data = NULL;
-  im->alpha_data = NULL;
-  g_snprintf (s, sizeof (s), "creat_%x_%x", (int)time(NULL), (int)rand());
-  im->filename = strdup (s);
-  im->width = 0;
-  im->height = 0;
-  im->border.left = 0;
-  im->border.right = 0;
-  im->border.top = 0;
-  im->border.bottom = 0;
-  im->pixmap = 0;
-  im->shape_mask = 0;
-  im->cache = 1;
-  im->mod.gamma = id->mod.gamma;
-  im->mod.brightness = id->mod.brightness;
-  im->mod.contrast = id->mod.contrast;
-  im->rmod.gamma = id->rmod.gamma;
-  im->rmod.brightness = id->rmod.brightness;
-  im->rmod.contrast = id->rmod.contrast;
-  im->gmod.gamma = id->gmod.gamma;
-  im->gmod.brightness = id->gmod.brightness;
-  im->gmod.contrast = id->gmod.contrast;
-  im->bmod.gamma = id->bmod.gamma;
-  im->bmod.brightness = id->bmod.brightness;
-  im->bmod.contrast = id->bmod.contrast;
-  im->shape_color.r = -1;
-  im->shape_color.g = -1;
-  im->shape_color.b = -1;
-  /* Init PNG Reader */
-  transp = 0;
-  png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
-  if (!png_ptr)
-    return NULL;
-  
-  info_ptr = png_create_info_struct(png_ptr);
-  if (!info_ptr)
-    {
-      png_destroy_read_struct(&png_ptr, NULL, NULL);
-      return NULL;
-    }
-  
-  if (setjmp(png_ptr->jmpbuf))
-    {
-      png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-      return NULL;
-    }
-  
-  if (info_ptr->color_type == PNG_COLOR_TYPE_RGB_ALPHA)
-    {
-      png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-      return NULL;
-    }
-
-  io_info.data = data;
-  io_info.ptr = data;
-  io_info.end = data + data_size;
-  png_set_read_fn(png_ptr, (void *)(&io_info), (png_rw_ptr)_gdk_imlib_png_io_read);
-  
-  /* Read Header */
-  png_read_info(png_ptr, info_ptr);
-  png_get_IHDR(png_ptr, info_ptr, &ww, &hh, &bit_depth, &color_type, &interlace_type,
-	       NULL, NULL);
-  im->rgb_width = ww;
-  im->rgb_height = hh;  
-  /* Setup Translators */
-  if (color_type == PNG_COLOR_TYPE_PALETTE)
-    png_set_expand(png_ptr);
-  png_set_strip_16(png_ptr);
-  png_set_packing(png_ptr);
-  if (png_get_valid(png_ptr, info_ptr, PNG_INFO_tRNS))
-    png_set_expand(png_ptr);
-  png_set_filler(png_ptr, 0xff, PNG_FILLER_AFTER);
-  im->rgb_data = malloc(ww * hh * 3);
-  if (!(im->rgb_data))
-    {
-      free(im->filename);
-      free(im);
-      png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-      return NULL;
-    }
-  lines = (unsigned char **)malloc(hh * sizeof(unsigned char *));
-  
-  if (lines == NULL)
-    {
-      free(im->filename);
-      free(im);
-      free(im->rgb_data);
-      png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-      return NULL;
-    }
-  for (i = 0; i < hh; i++)
-    {
-      if ((lines[i] = malloc(ww * (sizeof(unsigned char) * 4))) == NULL)
-	{
-	  int                 n;
-	  
-	  free(im->filename);
-	  free(im);
-	  free(im->rgb_data);
-	  for (n = 0; n < i; n++)
-	    free(lines[n]);
-	  free(lines);
-	  png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-	  return NULL;
-	}
-    }
-  png_read_image(png_ptr, lines);
-  png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
-  ptr = im->rgb_data;
-  if ((color_type == PNG_COLOR_TYPE_GRAY) ||
-      (color_type == PNG_COLOR_TYPE_GRAY_ALPHA))
-    {
-      for (y = 0; y < hh; y++)
-	{
-	  ptr2 = lines[y];
-	  for (x = 0; x < ww; x++)
-	    {
-	      r = *ptr2++;
-	      a = *ptr2++;
-	      if (a < 128)
-		{
-		  *ptr++ = 255;
-		  *ptr++ = 0;
-		  *ptr++ = 255;
-		  transp = 1;
-		}
-	      else
-		{
-		  *ptr++ = r;
-		  *ptr++ = r;
-		  *ptr++ = r;
-		}
-	    }
-	}
-    }
-  else
-    {
-      for (y = 0; y < hh; y++)
-	{
-	  ptr2 = lines[y];
-	  for (x = 0; x < ww; x++)
-	    {
-	      r = *ptr2++;
-	      g = *ptr2++;
-	      b = *ptr2++;
-	      a = *ptr2++;
-	      if (a < 128)
-		{
-		  *ptr++ = 255;
-		  *ptr++ = 0;
-		  *ptr++ = 255;
-		  transp = 1;
-		}
-	      else
-		{
-		  if ((r == 255) && (g == 0) && (b == 255))
-		    r = 254;
-		  *ptr++ = r;
-		  *ptr++ = g;
-		  *ptr++ = b;
-		}
-	    }
-	}
-    }
-  for (i = 0; i < hh; i++)
-    free(lines[i]);
-  free(lines);
-  if (transp)
-    {
-      im->shape_color.r = 255;
-      im->shape_color.g = 0;
-      im->shape_color.b = 255;
-    }
-  if (id->cache.on_image)
-    _gdk_imlib_add_image(im, im->filename);
-  _gdk_imlib_calc_map_tables(im);
-  return im;
-#else
-return NULL;
-#endif /* HAVE_LIBPNG */
-
-}
 
 #include <signal.h>
 #include <sys/wait.h>
