@@ -157,7 +157,7 @@ make_win()
    win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
    gtk_signal_connect(GTK_OBJECT(win), "delete_event",
 		      GTK_SIGNAL_FUNC(kill_win), NULL);
-   gtk_container_border_width(GTK_CONTAINER(win), 4);
+   gtk_container_set_border_width(GTK_CONTAINER(win), 4);
    gtk_window_set_policy(GTK_WINDOW(win), 0, 0, 1);
    gtk_window_set_title(GTK_WINDOW(win), "Imlib Config Editor");
    gtk_window_set_wmclass(GTK_WINDOW(win), "Imlib Config Editor", "Config");
@@ -354,7 +354,7 @@ showhide(GtkWidget * widget, GtkWidget * w)
       gtk_widget_hide(w);
    else
      {
-	gtk_window_position(GTK_WINDOW(w), GTK_WIN_POS_MOUSE);
+	gtk_window_set_position(GTK_WINDOW(w), GTK_WIN_POS_MOUSE);
 	gtk_widget_show(w);
      }
 }
@@ -509,16 +509,20 @@ read_imrc(FILE * f)
 	       }
 	     if (!strcasecmp(s1, "Mit-Shm"))
 	       {
+#ifdef HAVE_SHM
 		  if (!strcasecmp(s2, "on"))
 		     conf.mitshm = 1;
 		  else
+#endif
 		     conf.mitshm = 0;
 	       }
 	     if (!strcasecmp(s1, "SharedPixmaps"))
 	       {
+#ifdef HAVE_SHM
 		  if (!strcasecmp(s2, "on"))
 		     conf.sharedpixmap = 1;
 		  else
+#endif
 		     conf.sharedpixmap = 0;
 	       }
 	     if (!strcasecmp(s1, "FastRender"))
@@ -1227,9 +1231,9 @@ click_list(GtkWidget * widget, gint row)
 void
 add_onoff_visual(GtkWidget * w, char *title)
 {
-   GtkWidget          *check, *box, *box2, *clist;
+   GtkWidget          *check, *box, *box2, *clist, *scrolled_win;
    char                s[256], *ss[3];
-   char               *titles[] =
+   const char         *titles[] =
    {
       "Visual Type",
       "Depth",
@@ -1251,9 +1255,11 @@ add_onoff_visual(GtkWidget * w, char *title)
    gtk_box_pack_start(GTK_BOX(w), box2, TRUE, TRUE, 0);
    gtk_widget_show(box2);
 
+   scrolled_win = gtk_scrolled_window_new (NULL, NULL);
    clist = gtk_clist_new_with_titles(3, titles);
-   gtk_box_pack_start(GTK_BOX(w), clist, TRUE, TRUE, 0);
-   gtk_clist_set_policy(GTK_CLIST(clist), GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC);
+   gtk_box_pack_start(GTK_BOX(w), scrolled_win, TRUE, TRUE, 0);
+   gtk_container_add (GTK_CONTAINER (scrolled_win), clist);
+   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_win), GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC);
    gtk_signal_connect(GTK_OBJECT(clist), "select_row", GTK_SIGNAL_FUNC(click_list), NULL);
    gtk_clist_freeze(GTK_CLIST(clist));
    for (i = 0; i < vis_num; i++)
@@ -1330,7 +1336,11 @@ init_conf()
    conf.dither = 1;
    conf.remap = 1;
    conf.highquality = 0;
+#ifdef HAVE_SHM
    conf.mitshm = 1;
+#else
+   conf.mitshm = 0;
+#endif
    conf.shmmax = 0;
    conf.shmmaxsize = 1000000;
    conf.sharedpixmap = 0;
@@ -1434,7 +1444,7 @@ main(int argc, char **argv)
 		   "3   Mb", 3 * 1024 * 1024,
 		   "4   Mb", 4 * 1024 * 1024);
    add_onoff(pg2, "Use Ordered Dithering (Faster)", &conf.ordered);
-   add_onoff(pg2, "MIT-SHM Shared Memery Enabled", &conf.mitshm);
+   add_onoff(pg2, "MIT-SHM Shared Memory Enabled", &conf.mitshm);
    add_onoff(pg2, "Shared Pixmaps", &conf.sharedpixmap);
    add_onoff(pg2, "Fast Render", &conf.fastrender);
    add_onoff(pg2, "Imagemagick & NETPBM Fallback", &conf.fallback);
